/******************************************************************************/
/*                                                                            */
/*                Advanced Navigation Packet Protocol Library                 */
/*                Java Language Spatial Dual SDK, Version 7.0                 */
/*                    Copyright 2023, Advanced Navigation                     */
/*                                                                            */
/******************************************************************************/
/*
 * Copyright (C) 2023 Advanced Navigation
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

package com.advancednavigation.anPackets;

/* Dual Antenna Configuration */
public class ANPacket196
{
	public static final int LENGTH = 17;

	public static final String[] OFFSET_TYPE_STRINGS = {
		"Manual Offset",
		"Automatic Offset"
		};
	public static final String[] AUTOMATIC_OFFSET_ORIENTATION_STRINGS = {
		"Primary Front and Secondary Rear",
		"Primary Rear and Secondary Front",
		"Primary Right and Secondary Left",
		"Primary Left and Secondary Right"
		};
	
	public Boolean permanent;
	public int offsetType;
	public int automaticOffsetOrientation;
	public float[] manualOffset;
	
	public ANPacket196 ()
	{
		manualOffset = new float[3];
	}
	
	public ANPacket196(ANPacket packet)
	{
		permanent = packet.data[0] != 0;
		offsetType = packet.data[1] & 0xFF;
		automaticOffsetOrientation = packet.data[3] & 0xFF;
		manualOffset = new float[3];
		manualOffset[0] = TypeConversion.bytesToFloat(packet.data, 5);
		manualOffset[1] = TypeConversion.bytesToFloat(packet.data, 9);
		manualOffset[2] = TypeConversion.bytesToFloat(packet.data, 13);
	}

	public ANPacket toANPacket()
	{
		ANPacket packet = new ANPacket(LENGTH, ANPacket.PACKET_ID_DUAL_ANTENNA_CONFIGURATION);
		packet.data[0] = (byte) (permanent ? 1 : 0);
		packet.data[1] = (byte) (offsetType & 0xFF);
		packet.data[3] = (byte) (automaticOffsetOrientation & 0xFF);
		TypeConversion.floatToBytes(packet.data, 5, manualOffset[0]);
		TypeConversion.floatToBytes(packet.data, 9, manualOffset[1]);
		TypeConversion.floatToBytes(packet.data, 13, manualOffset[2]);
		return packet;
	}

	public String offsetTypeString()
	{
		if(offsetType >= 0 && offsetType < OFFSET_TYPE_STRINGS.length)
		{
			return OFFSET_TYPE_STRINGS[offsetType];
		}
		else
		{
			return "Unknown";
		}
	}
	
	public String automaticOffsetOrientationString()
	{
		if(automaticOffsetOrientation >= 0 && automaticOffsetOrientation < AUTOMATIC_OFFSET_ORIENTATION_STRINGS.length)
		{
			return AUTOMATIC_OFFSET_ORIENTATION_STRINGS[automaticOffsetOrientation];
		}
		else
		{
			return "Unknown";
		}
	}
}
