/******************************************************************************/
/*                                                                            */
/*                Advanced Navigation Packet Protocol Library                 */
/*                Java Language Spatial Dual SDK, Version 7.0                 */
/*                    Copyright 2023, Advanced Navigation                     */
/*                                                                            */
/******************************************************************************/
/*
 * Copyright (C) 2023 Advanced Navigation
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

package com.advancednavigation.anPackets;

/* File Transfer Acknowledge */
public class ANPacket8
{
	public static final int LENGTH = 9;

	// Response
	public static final int FILE_TRANSFER_COMPLETED_SUCCESSFULLY = 0;
	public static final int FILE_TRANSFER_READY = 1;
	public static final int FILE_TRANSFER_INDEX_MISMATCH = 2;
	public static final int FILE_TRANSFER_REFUSED = 64;
	public static final int FILE_TRANSFER_BAD_METADATA = 65;
	public static final int FILE_TRANSFER_TIMEOUT = 66;
	public static final int FILE_TRANSFER_RETRY_ERROR = 67;
	public static final int FILE_TRANSFER_STORAGE_ERROR = 68;
	public static final int FILE_TRANSFER_DATA_INVALID = 69;
	public static final int FILE_TRANSFER_PACKET_LENGTH_INVALID = 70;
	public static final int FILE_TRANSFER_TOTAL_SIZE_INVALID = 71;
	public static final int FILE_TRANSFER_OVERFLOW_ERROR = 72;
	public static final int FILE_TRANSFER_BUSY = 73;
	public static final int FILE_TRANSFER_CANCELLED = 74;
	public static final int FILE_TRANSFER_INCORRECT_DEVICE = 75;
	public static final int FILE_TRANSFER_FILE_NOT_FOUND = 128;
	public static final int FILE_TRANSFER_ACCESS_DENIED = 129;

	public long uniqueId;
	public long dataIndex;
	public int responseCode;

	public ANPacket8(ANPacket packet)
	{
		uniqueId = TypeConversion.bytesToUInt32(packet.data, 0);
		dataIndex = TypeConversion.bytesToUInt32(packet.data, 4);
		responseCode = packet.data[8];
	}

	public String getResponseString()
	{
		String response;
		switch (responseCode)
		{
			case FILE_TRANSFER_COMPLETED_SUCCESSFULLY:
				response = "Completed Successfully";
				break;
			case FILE_TRANSFER_READY:
				response = "Ready";
				break;
			case FILE_TRANSFER_INDEX_MISMATCH:
				response = "Index Mismatch";
				break;
			case FILE_TRANSFER_REFUSED:
				response = "Refused";
				break;
			case FILE_TRANSFER_BAD_METADATA:
				response = "Bad Metadata";
				break;
			case FILE_TRANSFER_TIMEOUT:
				response = "Timeout";
				break;
			case FILE_TRANSFER_RETRY_ERROR:
				response = "Retry Error";
				break;
			case FILE_TRANSFER_STORAGE_ERROR:
				response = "Storage Error";
				break;
			case FILE_TRANSFER_DATA_INVALID:
				response = "Data Invalid";
				break;
			case FILE_TRANSFER_PACKET_LENGTH_INVALID:
				response = "Length Invalid";
				break;
			case FILE_TRANSFER_TOTAL_SIZE_INVALID:
				response = "Size Invalid";
				break;
			case FILE_TRANSFER_OVERFLOW_ERROR:
				response = "Overflow Error";
				break;
			case FILE_TRANSFER_BUSY:
				response = "Busy";
				break;
			case FILE_TRANSFER_CANCELLED:
				response = "Cancelled";
				break;
			case FILE_TRANSFER_INCORRECT_DEVICE:
				response = "Incorrect Device";
				break;
			case FILE_TRANSFER_FILE_NOT_FOUND:
				response = "File Not Found";
				break;
			case FILE_TRANSFER_ACCESS_DENIED:
				response = "Access Denied";
				break;
			default:
				response = "Unknown Error";
				break;
		}
		return response;
	}
}
