/******************************************************************************/
/*                                                                            */
/*                Advanced Navigation Packet Protocol Library                 */
/*                Java Language Spatial Dual SDK, Version 7.0                 */
/*                    Copyright 2023, Advanced Navigation                     */
/*                                                                            */
/******************************************************************************/
/*
 * Copyright (C) 2023 Advanced Navigation
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

package com.advancednavigation.anPackets;

import java.util.Date;

/* Basestation */
public class ANPacket80
{
	public static final int LENGTH = 45;

	public static final int GNSS_NO_FIX = 0;
	public static final int GNSS_2D_FIX = 1;
	public static final int GNSS_3D_FIX = 2;
	public static final int GNSS_SBAS_FIX = 3;
	public static final int GNSS_DIFFERENTIAL_FIX = 4;
	public static final int GNSS_OMNISTAR_FIX = 5;
	public static final int GNSS_RTK_FLOAT_FIX = 6;
	public static final int GNSS_RTK_FIXED_FIX = 7;

	public long unixTimeStamp;
	public long microseconds;
	public Date time;
	double[] absolutePosition = new double[3];
	float[] relativePosition = new float[3];
	int gnssFixStatus;
	
	public ANPacket80(ANPacket packet)
	{
		unixTimeStamp  = TypeConversion.bytesToUInt32(packet.data, 0);
		microseconds  = TypeConversion.bytesToUInt32(packet.data, 4);
		time = new Date(unixTimeStamp * 1000 + microseconds / 1000);
		absolutePosition[0] = TypeConversion.bytesToDouble(packet.data, 8);
		absolutePosition[1] = TypeConversion.bytesToDouble(packet.data, 16);
		absolutePosition[2] = TypeConversion.bytesToDouble(packet.data, 24);
		relativePosition[0] = TypeConversion.bytesToFloat(packet.data, 32);
		relativePosition[1] = TypeConversion.bytesToFloat(packet.data, 36);
		relativePosition[2] = TypeConversion.bytesToFloat(packet.data, 40);
		gnssFixStatus = packet.data[44];
	}
}
